==> jc-1.4.0.tar.gz: javax/print/attribute/standard/JobOriginatingUserName.h <==
// public final class javax.print.attribute.standard.JobOriginatingUserName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax
// @dep_class b46bd3ba6baa26e6 javax_print_attribute_standard_JobOriginatingUserName

// header file dependencies
// @dep_header javax_print_attribute_TextSyntax

#include "javax/print/attribute/TextSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobOriginatingUserName_H_
#define _JC_javax_print_attribute_standard_JobOriginatingUserName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs	_jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs	_jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$refs	_jc_javax_print_attribute_standard_JobOriginatingUserName$refs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs	_jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object	_jc_javax_print_attribute_standard_JobOriginatingUserName$object;

typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct	_jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods	_jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtable	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtype	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobOriginatingUserName;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct _jc_javax_print_attribute_standard_JobOriginatingUserName$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobOriginatingUserName$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *);

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_JobOriginatingUserName$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobOriginatingUserName$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobOriginatingUserName$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobOriginatingUserName$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_JobOriginatingUserName$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobOriginatingUserName$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobOriginatingUserName$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods	javax_print_attribute_standard_JobOriginatingUserName;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$refs {
    _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs	javax_print_attribute_standard_JobOriginatingUserName;
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
    _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs	javax_print_attribute_standard_JobOriginatingUserName;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object {
	_jc_javax_print_attribute_standard_JobOriginatingUserName$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobOriginatingUserName$vtype _jc_javax_print_attribute_standard_JobOriginatingUserName$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobOriginatingUserName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobOriginatingUserName$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobOriginatingUserName_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/JobOriginatingUserName.h <==
// public final class javax.print.attribute.standard.JobOriginatingUserName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax
// @dep_class b46bd3ba6baa26e6 javax_print_attribute_standard_JobOriginatingUserName

// header file dependencies
// @dep_header javax_print_attribute_TextSyntax

#include "javax/print/attribute/TextSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobOriginatingUserName_H_
#define _JC_javax_print_attribute_standard_JobOriginatingUserName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs	_jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs	_jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$refs	_jc_javax_print_attribute_standard_JobOriginatingUserName$refs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs	_jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object	_jc_javax_print_attribute_standard_JobOriginatingUserName$object;

typedef struct _jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct	_jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods	_jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtable	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtype	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobOriginatingUserName;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobOriginatingUserName$fields_struct _jc_javax_print_attribute_standard_JobOriginatingUserName$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobOriginatingUserName$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_JobOriginatingUserName$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobOriginatingUserName$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobOriginatingUserName$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobOriginatingUserName$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_JobOriginatingUserName$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobOriginatingUserName$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobOriginatingUserName$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$vmethods	javax_print_attribute_standard_JobOriginatingUserName;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$refs {
    _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_refs	javax_print_attribute_standard_JobOriginatingUserName;
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
    _jc_javax_print_attribute_standard_JobOriginatingUserName$sub_nonrefs	javax_print_attribute_standard_JobOriginatingUserName;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobOriginatingUserName$object {
	_jc_javax_print_attribute_standard_JobOriginatingUserName$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobOriginatingUserName$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobOriginatingUserName$vtype _jc_javax_print_attribute_standard_JobOriginatingUserName$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobOriginatingUserName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobOriginatingUserName$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobOriginatingUserName_H_ */
